==> tecfy_core_package-0.1.65.tar.gz: lib/models/notification_app.model.dart <==
part of tecfy_core_client_package;

class NotificationApp extends BaseModel {
  String id;
  int type;
  bool showNowOnly;
  String titleAr;
  String titleEn;
  String get title => LocalConfigService.isArabic ? titleAr : titleEn;
  String messageAr;
  String messageEn;
  String get message => LocalConfigService.isArabic ? messageAr : messageEn;
  bool seen;
  String ownerUserId;
  String payload;
  DateTime time;

  NotificationApp({
    this.id,
    this.type,
    this.showNowOnly,
    this.titleAr,
    this.titleEn,
    this.messageAr,
    this.messageEn,
    this.seen,
    this.ownerUserId,
    this.time,
    this.payload,
  });
  String get timeString => time == null
      ? ''
      : intl.DateFormat("MMM-dd hh:mm a")
          .format(time.toLocal()); //. time?.toString() ?? '-';

  NotificationApp.fromMap(Map<String, dynamic> row) {
    id = row['id'];
    type = row['type'];
    showNowOnly = row['showNowOnly'] ?? false;
    titleAr = row['titleAr'] ?? '';
    titleEn = row['titleEn'] ?? '';
    messageAr = row['messageAr'] ?? '';
    messageEn = row['messageEn'] ?? '';
    seen = row['seen'] == 1 || row['seen'] == true;
    ownerUserId = row['ownerUserId'] ?? '';
    payload = row['payload'] ?? '';
    if (row['createdTime'] != null) {
      time = BaseModel.parseUTC(row['createdTime']);
      //DateTime.tryParse(row['createdTime'],  );
    } else {
      time = DateTime.fromMillisecondsSinceEpoch(row['time'] ?? 0, isUtc: true);
    }
  }

  toMapDb() {
    return {
      'id': id,
      'type': type,
      //'showNowOnly': showNowOnly,
      'titleAr': titleAr,
      'titleEn': titleEn,
      'messageAr': messageAr,
      'messageEn': messageEn,
      'seen': seen ? 1 : 0,
      //'ownerUserId': ownerUserId,
      'time': time.millisecondsSinceEpoch,
      'payload': payload,
    };
  }

  @override
  String get displayName => null;

  @override
  String get idValue => null;
}

==> tecfy_core_package-1.0.5.tar.gz: lib/models/notification_app.model.dart <==
part of tecfy_core_client_package;

class NotificationApp extends BaseModel {
  late String id;
  late int type;
  bool showNowOnly = false;
  late String titleAr;
  late String titleEn;
  String get title => LocalConfigService.isArabic ? titleAr : titleEn;
  late String messageAr;
  late String messageEn;
  String get message => LocalConfigService.isArabic ? messageAr : messageEn;
  bool seen = false;
  late String ownerUserId;
  String? payload;
  late DateTime time;

  NotificationApp({
    required this.id,
    required this.type,
    this.showNowOnly = false,
    required this.titleAr,
    required this.titleEn,
    required this.messageAr,
    required this.messageEn,
    this.seen = false,
    required this.ownerUserId,
    required this.time,
    this.payload,
  });
  String get timeString => time == null
      ? ''
      : intl.DateFormat("MMM-dd hh:mm a")
          .format(time.toLocal()); //. time?.toString() ?? '-';

  NotificationApp.fromMap(Map<String, dynamic> row) {
    id = row['id'];
    type = row['type'];
    showNowOnly = row['showNowOnly'] ?? false;
    titleAr = row['titleAr'] ?? '';
    titleEn = row['titleEn'] ?? '';
    messageAr = row['messageAr'] ?? '';
    messageEn = row['messageEn'] ?? '';
    seen = row['seen'] == 1 || row['seen'] == true;
    ownerUserId = row['ownerUserId'] ?? '';
    payload = row['payload'] ?? '';
    if (row['createdTime'] != null) {
      time = BaseModel.parseUTC(row['createdTime']) ?? DateTime.now();
      //DateTime.tryParse(row['createdTime'],  );
    } else {
      time = DateTime.fromMillisecondsSinceEpoch(row['time'] ?? 0, isUtc: true);
    }
  }

  toMapDb() {
    return {
      'id': id,
      'type': type,
      //'showNowOnly': showNowOnly,
      'titleAr': titleAr,
      'titleEn': titleEn,
      'messageAr': messageAr,
      'messageEn': messageEn,
      'seen': seen ? 1 : 0,
      //'ownerUserId': ownerUserId,
      'time': time.millisecondsSinceEpoch,
      'payload': payload,
    };
  }

  @override
  String get displayName => titleAr;

  @override
  String get idValue => id;
}
